SystemOrganization addCategory: #GODEmailTests!

TestCase subclass: #MAILReceiverTest
	instanceVariableNames: 'list newdata receiver simpleMessage'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODEmailTests'!

!MAILReceiverTest methodsFor: 'initialize-release' stamp: 'LFSA 10/19/2014 23:12'!
setUp
	list := OrderedCollection new.
	newdata := GODData new.
	receiver := MAILReceiver new.

	simpleMessage := 'Return-Path: <megag@terra.com.br>
Delivered-To: giuliano@ime.usp.br
Received: (qmail 30297 invoked from network); 14 Apr 2006 17:01:01 -0000
Received: from birao.terra.com.br (200.176.10.197)
  by birosca.ime.usp.br with SMTP; 14 Apr 2006 17:01:01 -0000
Received: from bucavu.terra.com.br (bucavu.terra.com.br [200.176.10.6])
	by birao.terra.com.br (Postfix) with ESMTP id 85AB2108C012;
	Fri, 14 Apr 2006 14:04:16 -0300 (BRT)
X-Terra-Karma:         -2%
X-Terra-Hash: 49123a376960a827fe5daf9bd14db26c
Received-SPF: pass (bucavu.terra.com.br: domain of terra.com.br designates 200.176.10.6 as permitted sender) client-ip=200.176.10.6; envelope-from=megag@terra.com.br; helo=[192.168.0.100];
Received: from [192.168.0.100] (c9067dc7.virtua.com.br [201.6.125.199])
	(authenticated user megag)
	by bucavu.terra.com.br (Postfix) with ESMTP id 5F165153C0C4;
	Fri, 14 Apr 2006 14:04:16 -0300 (BRT)
Message-ID: <443FDE27.8010309@terra.com.br>
Date: Fri, 14 Apr 2006 14:38:47 -0300
From: Giuliano Mega <megag@terra.com.br>
User-Agent: Debian Thunderbird 1.0.7 (X11/20051017)
X-Accept-Language: en-us, en
MIME-Version: 1.0
To:  giuliano@ime.usp.br
CC:  giuliano.mega@gmail.com
Subject: e-mail simples
Content-Type: text/plain; charset=ISO-8859-1; format=flowed
Content-Transfer-Encoding: 8bit

Este  um e-mail simplrrimo.

'.! !

!MAILReceiverTest methodsFor: 'tests' stamp: 'LFSA 11/2/2014 01:17'!
testCache
	| collection count |
	count := 0.
	receiver pop3Client: (TUMock new when: #openOnHostNamed:port: do: [ :hostname :port |  
		TUMock new
		when: #loginUser:password: do: [ :user :password |	];
		when: #messageCount do: [ 1 ];
		when: #retrieveMessage: do: [ :index | count := count + 1. simpleMessage. ];
		when: #close do: [].
	]).
	receiver hostname: 'hostname'.
	receiver user: 'username'.
	receiver password: 'secret'.
	
	"First call. Should connect to server to get the new messages"
	self shouldnt: [collection := receiver receive] raise: Error.
	self assert: collection size equals: 1.
	self assert: ((collection at: 1) isKindOf: GODData) equals: true.
	self assert: count equals: 1.
	
	"Second call. There is no new messages so returns the cached one without a new server connection"
	self shouldnt: [collection := receiver receive] raise: Error.
	self assert: collection size equals: 1.
	self assert: ((collection at: 1) isKindOf: GODData) equals: true.
	self assert: count equals: 1.! !

!MAILReceiverTest methodsFor: 'tests' stamp: 'LFSA 10/19/2014 23:12'!
testConvertToGODData
	| data |
	data := MAILReceiver convertToGODData: simpleMessage.
	self assert: data origin equals: 'email'.
	self assert: data author equals: 'Giuliano Mega <megag@terra.com.br>'.
	self assert: data title equals: 'e-mail simples'.
	self assert: data timestamp equals: ('14 Apr 2006 14:38:47 -0300' asTimeStamp).
	self assert: data content equals: 'Este  um e-mail simplrrimo'.! !

!MAILReceiverTest methodsFor: 'tests' stamp: 'LFSA 11/2/2014 01:20'!
testReceive
	| collection portReceived |
	receiver pop3Client: (TUMock new when: #openOnHostNamed:port: do: [ :hostname :port |  
		portReceived := port.
		TUMock new
		when: #loginUser:password: do: [ :user :password |	];
		when: #messageCount do: [ 1 ];
		when: #retrieveMessage: do: [ :index | simpleMessage ];
		when: #close do: [].
	]).
	receiver hostname: 'hostname'.
	receiver user: 'username'.
	receiver password: 'secret'.
	receiver port: 42.
	self shouldnt: [collection := receiver receive] raise: Error.
	self assert: collection size equals: 1.
	self assert: ((collection at: 1) isKindOf: GODData) equals: true.
	self assert: portReceived equals: 42.! !

!MAILReceiverTest methodsFor: 'tests' stamp: 'LFSA 10/14/2014 19:48'!
testReceiveLoginFailed
	receiver pop3Client: (TUMock new when: #openOnHostNamed: do: [ :hostname |  
		TUMock new
		when: #loginUser:password: do: [ :user :password |	POP3LoginError signal: 'Unsupported login procedure.' ].
	]).
	receiver hostname: 'hostname'.
	receiver user: 'user'.
	receiver password: 'secret'.
	self should: [receiver receive] raise: Error.! !

!MAILReceiverTest methodsFor: 'tests' stamp: 'LFSA 9/28/2014 15:45'!
testReceiveWithNoHostname
	receiver user: 'username'.
	receiver password: 'secret'.
	self should: [receiver receive] raise: Error.! !

!MAILReceiverTest methodsFor: 'tests' stamp: 'LFSA 9/28/2014 15:46'!
testReceiveWithNoPassword
	receiver hostname: 'hostname'.
	receiver user: 'username'.
	self should: [receiver receive] raise: Error.! !

!MAILReceiverTest methodsFor: 'tests' stamp: 'LFSA 9/28/2014 15:46'!
testReceiveWithNoUser
	receiver hostname: 'hostname'.
	receiver password: 'secret'.
	self should: [receiver receive] raise: Error.! !

TestCase subclass: #MAILSenderTest
	instanceVariableNames: 'sender'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODEmailTests'!

!MAILSenderTest methodsFor: 'initialize-release' stamp: 'LFSA 10/19/2014 23:13'!
setUp
	sender := MAILSender new.! !

!MAILSenderTest methodsFor: 'tests' stamp: 'LFSA 11/2/2014 20:43'!
testSend
	| godData receivedPort receivedFrom receivedTo receivedText |
	godData := GODData new content: 'Content'; title: 'Title'.
	sender smtpClient: (TUMock new when: #openOnHostNamed:port: do: [ :hostname :port |  
		receivedPort := port.
		TUMock new
		when: #user: do: [ :user | ];
		when: #password: do: [ :password | ];
		when: #login do: [ ];
		when: #initiateSession do: [ ];
		when: #mailFrom:to:text: do: [ :from :to :text | receivedFrom := from. receivedTo := to. receivedText := text. ];
		when: #quit do: [];
		when: #close do: [].
	]).
	sender hostname: 'hostname'.
	sender user: 'username'.
	sender password: 'secret'.
	
	self shouldnt: [sender send: godData to: 'foo@bar.com'] raise: Error.
	self assert: (receivedTo at: 1) equals: 'foo@bar.com'.
	self assert: (receivedText includesSubString: ('Subject: ', 'Title')) equals: true.
	self assert: (receivedText includesSubString: ('To: ', 'foo@bar.com')) equals: true.
	self assert: (receivedText includesSubString: 'Content') equals: true.! !

!MAILSenderTest methodsFor: 'tests' stamp: 'LFSA 11/2/2014 21:13'!
testSendWithEmptyData
	| testData |
	testData := GODData new.
	sender smtpClient: (TUMock new when: #openOnHostNamed:port: do: [ :hostname :port |  
		TUMock new
		when: #user: do: [ :user | ];
		when: #password: do: [ :password | ];
		when: #login do: [ ];
		when: #initiateSession do: [ ];
		when: #mailFrom:to:text: do: [ :from :to :text | ];
		when: #quit do: [];
		when: #close do: [].
	]).
	sender hostname: 'hostname'.
	sender user: 'user'.
	sender password: 'pass'.

	self should: [sender send: testData to: 'bla@teste.com'] raise: Error.! !

!MAILSenderTest methodsFor: 'tests' stamp: 'LFSA 9/28/2014 15:19'!
testSendWithNoHostname
	| godData |
	godData := GODData new content: 'foo'.
	sender user: 'username'.
	sender password: 'secret'.
	self should: [sender send: godData to: 'foo@bar.com'] raise: Error.! !

!MAILSenderTest methodsFor: 'tests' stamp: 'LFSA 9/28/2014 15:20'!
testSendWithNoPassword
	| godData |
	godData := GODData new content: 'foo'.
	sender hostname: 'hostname'.
	sender user: 'username'.
	self should: [sender send: godData to: 'foo@bar.com'] raise: Error.! !

!MAILSenderTest methodsFor: 'tests' stamp: 'LFSA 9/28/2014 15:20'!
testSendWithNoUser
	| godData |
	godData := GODData new content: 'foo'.
	sender hostname: 'hostname'.
	sender password: 'secret'.
	self should: [sender send: godData to: 'foo@bar.com'] raise: Error.! !
